/*
 * led_receptor.c
 *
 * Created: 03/12/2021 14:29:43
 *  Author: 40008304
 */ 

#include "led_receptor.h"

volatile unsigned char intr_count;
volatile unsigned char timer_flag=0;
volatile unsigned char seconde=0;

void ADC_init(void)
{
	DDRB &=~(1<<PB3);										//Pin B3 en entree
	ADMUX |= (1<<MUX1)|(1<<MUX0)|(1<<ADLAR);				//MUX = 0010 donc sortie PB4 et ADLAR a 1 pour avoir les bits de poids fort en premier
	ADCSRA|= (1<<ADEN)|(1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0)|(1<<ADIE);		//ADEN conversion autorisee
															//On divise 16Mhz par 128 (125 KHz) < 200 KHz
															//Interruptions autorisees
	ADCSRB &= ~(0b111<<ADTS0);								//free-running mode
	sei();
};

void ADC_start_conversion(void)
{
	ADCSRA|=(1<<ADEN)|(1<<ADIE)|(1<<ADSC);
};

char ADC_read_value(void)
{
	ADCSRA|=(1<<ADSC);
	while(ADCSRA & (1<<ADSC));
	return ADCH;
};

float ADC_averaging(unsigned char val_ana)
{
	float valeur_finale=0;
	char precision;
	for(precision = 75; precision > 0 ; precision --)
	{
		valeur_finale = valeur_finale +(((val_ana * 0.01961) - valeur_finale) / 15);
	}
	return valeur_finale;
};

char measureLed1(void)
{
	char adcLed=0;
	
	if(timer_flag == 1)
	{
		if(led1_state==0)
		{
			led1_init();
			adcLed=ADCH;
		}
		else
		{
			led1_stop();
		}
	}
	return adcLed;
};

char measureLed2(void)
{
	char adcLed=0;
	
	if(timer_flag == 1)
	{
		if(led2_state==0)
		{
			led2_init();
			adcLed=ADCH;
		}
		else
		{
			led2_stop();
		}
		timer_flag=0;
	}
	return adcLed;
};

unsigned char compareLed(float led1,float led2)
{
	float adcLed1 = led1;
	float adcLed2 = led2;
	float adcCompare = led1 - led2;
	if (adcCompare < VOLTMIN)	// adcLed2 > adcLed1
	{
		return LEFT;
	}
	else if (adcCompare > VOLTMIN)
	{
		return RIGHT;
	}
	else
	{
		if((adcLed1 > VOLTMIN) && (adcLed2 > VOLTMIN))
		{
			return NOTHING;
		}
		else
		{
			return FRONT;
		};
	};
};
